@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use UI::Various::core;
 use UI::Various::Check;
@@ -96,7 +96,7 @@ sub _prepare($$$)
 		->Checkbutton(-text => $self->text,
 			      -variable => $self->{var},
 			      @attributes)
-		->grid(-row => $row, -column => $column));
+		->grid(-row => $row, -column => $column, -sticky => 'w'));
     return 0;
 }
 
