@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use UI::Various::core;
 use UI::Various::Listbox;
@@ -121,7 +121,7 @@ sub _prepare($$$)
 
 =head2 B<_add> - add new element
 
-C<PoorTerm>'s specific implementation of
+C<Tk>'s specific implementation of
 L<UI::Various::Listbox::add|UI::Various::Listbox/add - add new element>
 
 =cut
@@ -136,9 +136,31 @@ sub _add($@)
 
 #########################################################################
 
+=head2 B<_modify> - modify listbox
+
+C<Tk>'s specific implementation of
+L<UI::Various::Listbox::modify|UI::Various::Listbox/modify - modify
+element>)
+
+=cut
+
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
+
+sub _modify($$$)
+{
+    my ($self, $index, $value) = @_;
+    if (defined $self->_tk)
+    {
+	$self->_tk->insert($index, $value);
+	$self->_tk->delete($index + 1);
+    }
+}
+
+#########################################################################
+
 =head2 B<_remove> - remove element
 
-C<PoorTerm>'s specific implementation of
+C<Tk>'s specific implementation of
 L<UI::Various::Listbox::remove|UI::Various::Listbox/remove - remove element>
 
 =cut
@@ -155,7 +177,7 @@ sub _remove($$)
 
 =head2 B<_replace> - replace all elements
 
-C<PoorTerm>'s specific implementation of
+C<Tk>'s specific implementation of
 L<UI::Various::Listbox::replace|UI::Various::Listbox/replace - replace all
 elements>
 
@@ -177,7 +199,7 @@ sub _replace($@)
 
 =head2 B<_selected> - get current selection of listbox
 
-C<PoorTerm>'s specific implementation of
+C<Tk>'s specific implementation of
 L<UI::Various::Listbox::selected|UI::Various::Listbox/selected - get current
 selection of listbox>
 
