@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use UI::Various::core;
 use UI::Various::Radio;
@@ -101,7 +101,7 @@ sub _prepare($$$)
 	    $grid->Radiobutton(	-value => $self->{_button_keys}[$_],
 				-text => $self->{_button_values}[$_],
 				-variable => $self->{var})
-	    ->grid(-row => $_, -column => 0);
+	    ->grid(-row => $_, -column => 0, -sticky => 'w');
     }
     $self->_tk(\@tk);
     return 0;
